=======
Credits
=======

Development Lead
----------------
* `Mark van Koningsveld`_
* `Fedor Baart`_

.. _Mark van Koningsveld: https://www.tudelft.nl/citg/over-faculteit/afdelingen/hydraulic-engineering/sections/rivers-and-ports/staff/prof-dr-ir-m-mark-van-koningsveld
.. _Fedor Baart: https://www.deltares.nl/en/experts/fedor-baart-3/

 